@@ -5,7 +5,6 @@ import (
 	"context"
 	"crypto/rand"
 	"errors"
-	"flag"
 	"fmt"
 	"io"
 	"log"
@@ -66,9 +65,6 @@ func TestMain(m *testing.M) {
 		defer testutils.SetupSmb(1446, filepath.Join(cwd, "testdata/AD/SYSVOL"))()
 	}
 
-	testutils.InstallUpdateFlag()
-	flag.Parse()
-
 	m.Run()
 
 	if os.Getenv("GO_WANT_HELPER_PROCESS") != "1" {
@@ -121,7 +117,6 @@ socket: %s`, socket)), 0600)
 		"version":                     {args: []string{"version"}},
 	}
 	for name, tc := range tests {
-		tc := tc
 		t.Run(name, func(t *testing.T) {
 			_, err = runClient(t, confFile, tc.args...)
 			require.Error(t, err, "command should fail")
@@ -155,7 +150,6 @@ func TestCommandsTimeouts(t *testing.T) {
 		"0 is no timeout": {timeout: 0},
 	}
 	for name, tc := range tests {
-		tc := tc
 		t.Run(name, func(t *testing.T) {
 			// We only implement one command to test the client timeout functionality
 			timeoutServer := timeoutOnVersionServer{callbackHandled: make(chan struct{})}
@@ -196,8 +190,9 @@ client_timeout: %d`, socket, tc.timeout)), 0600)
 type confOption func(*confOptions)
 
 type confOptions struct {
-	adsysDir string
-	backend  string
+	adsysDir           string
+	backend            string
+	detectCachedTicket bool
 }
 
 func confWithAdsysDir(adsysDir string) confOption {
@@ -212,6 +207,12 @@ func confWithBackend(backend string) confOption {
 	}
 }
 
+func confDetectCachedTicket(detectCachedTicket bool) confOption {
+	return func(o *confOptions) {
+		o.detectCachedTicket = detectCachedTicket
+	}
+}
+
 // createConf generates an adsys configuration in a temporary directory
 // It will use adsysDir for socket, cache and run dir if provided.
 func createConf(t *testing.T, opts ...confOption) (conf string) {
@@ -233,31 +234,33 @@ func createConf(t *testing.T, opts ...confOption) (conf string) {
 	confData := []byte(fmt.Sprintf(`
 # Service and client configuration
 verbose: 2
-socket: %s/socket
+socket: %[1]s/socket
 
 # Service only configuration
-cache_dir: %s/cache
-state_dir: %s/lib
-run_dir: %s/run
+cache_dir: %[1]s/cache
+state_dir: %[1]s/lib
+run_dir: %[1]s/run
 service_timeout: 30
 
 # Backend selection: sssd (default) or winbind
-ad_backend: %s
+ad_backend: %[2]s
 
 # SSSd configuration
 sssd:
   config: testdata/sssd-configs/sssd.conf-example.com
-  cache_dir: %s/sss_cache
+  cache_dir: %[1]s/sss_cache
 
 # Those are more for tests
-dconf_dir: %s/dconf
-sudoers_dir: %s/sudoers.d
-policykit_dir: %s/polkit-1
-apparmor_dir: %s/apparmor.d/adsys
-apparmorfs_dir: %s/apparmorfs
-systemunit_dir: %s/systemd/system
-global_trust_dir: %s/share/ca-certificates
-`, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.backend, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir))
+dconf_dir: %[1]s/dconf
+sudoers_dir: %[1]s/sudoers.d
+policykit_dir: %[1]s/polkit-1
+apparmor_dir: %[1]s/apparmor.d/adsys
+apparmorfs_dir: %[1]s/apparmorfs
+systemunit_dir: %[1]s/systemd/system
+global_trust_dir: %[1]s/share/ca-certificates
+
+detect_cached_ticket: %[3]t
+`, args.adsysDir, args.backend, args.detectCachedTicket))
 
 	testutils.WriteFile(t, confFile, confData, os.ModePerm)
 	require.NoError(t, os.MkdirAll(filepath.Join(args.adsysDir, "dconf"), 0750), "Setup: should create dconf dir")
@@ -409,7 +412,10 @@ func runDaemons() (teardown func()) {
 		go func() {
 			defer wg.Done()
 
-			if err := os.MkdirAll(socketDir, 0750); err != nil {
+			// 24.04 introduced some polkit changes that make the daemon drop root privileges before executing. In order
+			// to be able to connect to the bus and run polkitd, we need more permissions in the socket directory.
+			//nolint:gosec
+			if err := os.MkdirAll(socketDir, 0755); err != nil {
 				log.Fatalf("Setup: can’t create %s socket directory: %v", answer, err)
 			}
 
